import express, { Express } from 'express';
import 'express-async-errors';
import { applyMiddleware, applyRoutes } from './util';
import middlewares from '../../middlewares';
import errorHandlers from '../../middlewares/errorHandlers';
import { Route, Wrapper } from './types';

const app = express();

export const startServer = (
  routes: Route[],
  customizablesMiddlewares?: Wrapper[],
  applyCommonsMiddlewares = true,
  applyCommonsErrors = true
): Express => {
  if (applyCommonsMiddlewares) applyMiddleware(middlewares, app);
  if (customizablesMiddlewares) applyMiddleware(customizablesMiddlewares, app);

  applyRoutes(routes, app);
  if (applyCommonsErrors) applyMiddleware(errorHandlers, app);

  return app;
};
